@@ -20,6 +20,7 @@ USA.
 */
 
 /* body.h
+ * added c_microstrip_win(), C.G.
  */
 
 #ifndef __BODY_H
@@ -35,6 +36,8 @@ short transtype_int (void);
 /*extern trans_win *microstrip_win (GtkWidget *);*/
 extern trans_win *microstrip_win (trans_gui *);
 extern trans_win *rectwaveguide_win (trans_gui *);
+extern trans_win *coax_win (trans_gui *);
+extern trans_win *c_microstrip_win (trans_gui *);
 
 #endif
 
