@@ -101,7 +101,7 @@ alphac (rectwaveguide *rw)
 {
 
   gfloat a, b, sigma, mur, f;
-  gfloat Rs,beta, k, f_c;
+  gfloat Rs, k, f_c;
   gfloat ac;
   short m, n, mmax, nmax;
 
@@ -195,7 +195,6 @@ void
 get_rectwaveguide_sub (trans_win *rwin,
 			 rectwaveguide *rw)
 {
-  short curr_unit;
 
 
   if (sscanf (gtk_entry_get_text(GTK_ENTRY (rwin->subparam_text[0])), 
@@ -374,15 +373,15 @@ analyze_rectwaveguide (GtkWidget *parent,
       
       if ((text = (char *) malloc(1000*sizeof(char)))  == NULL){
 	perror("results text error: malloc");
-	exit -1;
+	exit(-1);
       }
       if ((results = (char *) malloc(1000*sizeof(char)))  == NULL){
 	perror("results text error: malloc");
-	exit -1;
+	exit(-1);
       }
       if ((temp = (char *) malloc(1000*sizeof(char)))  == NULL){
 	perror("results text error: malloc");
-	exit -1;
+	exit(-1);
       }
       
       sprintf(results, "\nEffective dielectic constant, er_eff = %.4g\n", 
@@ -439,6 +438,7 @@ analyze_rectwaveguide (GtkWidget *parent,
 	free(results);
 	free(text);
 	free(temp);
+
         if (statusexists){
           if (statusint != CONSISTENT) {
             gtk_label_set_text (GTK_LABEL (rwin->status), "Values are consistent");
@@ -448,30 +448,31 @@ analyze_rectwaveguide (GtkWidget *parent,
 	
     } else {
       perror("malloc rw");
-      exit -1;
+      exit(-1);
     }
 
 }
 
 /*
- * synthesize_rectwaveguide - analysis function
+ * synthesize_rectwaveguide - synthesis function
  */
 void
 synthesize_rectwaveguide (GtkWidget *parent,
 		       trans_win *rwin)
 {
-  gchar *text, *results;
+  gchar *text, *results, *temp;
   rectwaveguide *rw;
   short required_unit;
   gfloat lambda_g;
   gfloat a, b, f;
   gfloat Z0;
   gfloat beta, k;
+  short m, n, mmax, nmax;
   
   /*allocate memory for text */
   if ((text = (char *) malloc(10*sizeof(char)))  == NULL){
     perror("text error: malloc");
-    exit -1;
+    exit(-1);
   }
 
   /*allocate memory for pointer rw */
@@ -514,6 +515,7 @@ synthesize_rectwaveguide (GtkWidget *parent,
 	sprintf(text,"%g", (float) (rw->a * conv_length[LENGTH_M][required_unit]));
 	gtk_entry_set_text (GTK_ENTRY (rwin->physical_param_text[0]), text);
       }
+
       k = kval (rw);
       beta = sqrt(pow(k,2.) - pow(kc(rw,1,0),2.0));
       lambda_g = (2. * M_PI)/beta;
@@ -524,35 +526,107 @@ synthesize_rectwaveguide (GtkWidget *parent,
 				(GTK_COMBO(rwin->physical_param_combo[2])->entry)));
       sprintf(text,"%g", (float) (rw->l * conv_length[LENGTH_M][required_unit]));
       gtk_entry_set_text (GTK_ENTRY (rwin->physical_param_text[2]), text);
-      rw->er_eff = (1.0 - pow((fc(rw,1,0)/rw->f),2.0));
+
+      if (kc(rw,1,0) <= k) {
+	/*propagating modes */
+	beta = sqrt(pow(k,2.) - pow(kc(rw,1,0),2.0));
+	lambda_g = (2. * M_PI)/beta;
+	rw->atten_cond = alphac (rw) * rw->l;
+	rw->atten_dielectric = alphad (rw) * rw->l;
+	rw->er_eff = (1.0 - pow((fc(rw,1,0)/rw->f),2.0));
+      } else { 
+	/*evanascent modes */	
+	rw->Z0 = 0;
+	rw->ang_l = 0;
+	rw->er_eff = 0;
+	rw->atten_dielectric = 0.0;
+	rw->atten_cond = alphac_cutoff (rw) * rw->l;
+      }
+
 
       free(text);
       if ((text = (char *) malloc(500*sizeof(char)))  == NULL){
         perror("results text error: malloc");
-        exit -1;
+        exit(-1);
       }
-
+      
       if ((results = (char *) malloc(500*sizeof(char)))  == NULL){
         perror("results text error: malloc");
-        exit -1;
+        exit(-1);
+      }
+      
+      if ((temp = (char *) malloc(1000*sizeof(char)))  == NULL){
+	perror("results text error: malloc");
+	exit(-1);
       }
 
-      sprintf(results, "Effective dielectic constant, er_eff = %.4g\n", rw->er_eff);
+      
+      sprintf(results, "\nEffective dielectic constant, er_eff = %.4g\n", 
+	      rw->er_eff);
+      required_unit = getunit(gtk_entry_get_text (GTK_ENTRY 
+						  (GTK_COMBO 
+						   (rwin->physical_param_combo[2])->entry)));
+      sprintf(text,"Conductor Losses = %.4g dB\n", 
+              rw->atten_cond);
+      strcat(results,text);
+      sprintf(text, "Dielectric Losses = %.4g dB\n", 
+              rw->atten_dielectric);
+      strcat(results, text);
+      
+      if (f >= (2.*fc(rw,1,0))) {
+	/* multiple modes possible in waveguide */
+	strcpy(text, "\nWarning: The following additional \nTE modes can propagate:\n");
+	strcat(results, text);
+	/*	  mmax = floor(f/fc(rw,1,0));*/
+	mmax = 5;
+	nmax = mmax;
+	strcpy(text, " ");
+	for (m = 2; m<= mmax; m++) {
+	  for (n=0; n<= nmax; n++) {
+	    if (f >= (fc(rw,m,n))){
+	      sprintf(temp,"TE(%u,%u) ",m, n);
+	      strcat(text,temp);
+	    }
+	  }
+	}
+	strcat(results,text);
+	strcat(results,"\n");
+      }
+      if (f >= fc(rw,1,1)){ /*TM(1,1) mode possible*/
+	strcpy(text, "\nWarning: The following additional \nTM modes can propagate:\n");
+	strcat(results, text);
+	/*	  mmax = floor(f/fc(rw,1,1));*/
+	mmax = 5;
+	nmax = mmax;
+	strcpy(text, " ");
+	for (m = 1; m<= mmax; m++) {
+	  for (n=1; n<= nmax; n++) {
+	    if (f >= (fc(rw,m,n))){
+	      sprintf(temp,"TM(%u,%u) ",m, n);
+	      strcat(text,temp);
+	    }
+	  }
+	}
+	strcat(results,text);
+	strcat(results,"\n");
+      }	  
+      
       gtk_label_set (GTK_LABEL (rwin->results_text), results);
-
       free(results);
       free(text);
+      free(temp);
+      
 
       if (statusexists){
         if (statusint != CONSISTENT) {
           gtk_label_set_text (GTK_LABEL (rwin->status), 
-			      "Tweak values and analyze to get more accurate synthesis");
+			      "Values are consistent");
         } 
       }
       statusint = CONSISTENT;
     } else {
       perror("malloc rw");
-      exit -1;
+      exit(-1);
     }
 }
 
@@ -591,7 +665,7 @@ void
 rectwaveguide_win (GtkWidget *parent)
      /*rectwaveguide_win (trans_gui *tg)*/
 {
-  short row, col;
+  short row;
 
   /* if there is a window that already exists kill it first */
   if (main_body_window != NULL)   {
