@@ -24,12 +24,14 @@ USA.
  */
 
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include <string.h>
 #include <math.h>
 #include <sys/stat.h>
 
+#include <config.h>
 #include "setup.h"
 
 void
@@ -37,8 +39,6 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 {
   GtkWidget *vbox;
   GtkWidget *label;
-  GList *glist = NULL;
-  GtkWidget *combo;
   GtkTooltips *tooltips,*ctooltips,*ptooltips,*etooltips,*btooltips;
   short row, col;
   gchar *textentry;
@@ -66,12 +66,15 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   tvalue = g_malloc(sizeof(*tvalue));
   setup_values(ttype, tvalue);
 
+
   /*allocate memory for textentry */
   if ((textentry = (char *) malloc(20*sizeof(char)))  == NULL){
     perror("help text error: malloc");
     return;
   }
 
+#ifdef HAVE_IMLIB
+
   if ((image_dir = (char *) malloc(50*sizeof(char))) == NULL){
     perror("image dir malloc error:");
     return;
@@ -82,6 +85,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
     return;
   }
 
+#endif
 
   /* Add a vbox and hbox to start the packing */
   main_body_window = gtk_vbox_new (FALSE, 5);
@@ -90,24 +94,33 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   vbox = gtk_vbox_new (FALSE, 5);
 
   /* pack these in the parent window */
-  gtk_container_add (GTK_CONTAINER (parent), main_body_window);
-  gtk_box_pack_start (GTK_BOX (main_body_window), hboxtop, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (hboxtop), vbox, FALSE, FALSE, 0);
+  /*  gtk_container_add (GTK_CONTAINER (parent), main_body_window);*/
+  gtk_box_pack_start (GTK_BOX (parent), main_body_window, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (main_body_window), hboxtop, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (hboxtop), vbox, TRUE, TRUE, 0);
 
   switch (ttype) {
-  case MICROSTRIP:
+  case MICROSTRIP :
     twin->drawing_frame = gtk_frame_new ("Microstrip");
     break;
-  case RECTWAVEGUIDE:
+  case RECTWAVEGUIDE :
     twin->drawing_frame = gtk_frame_new ("Rectangular Waveguide");
     break;
+  case COAX :
+    twin->drawing_frame = gtk_frame_new ("Coaxial Line");
+    break;
+  case C_MICROSTRIP :
+    twin->drawing_frame = gtk_frame_new ("Coupled Microstrip");
+    break;
   }
     
   gtk_container_add (GTK_CONTAINER (vbox), twin->drawing_frame);
 
   /* Grab the filename for drawing */
 
+#ifdef HAVE_IMLIB
   sprintf (image_dir, "%s/transcalc/images/",DATADIR);    
+/*  sprintf(image_dir, "../images/");*/
   if (stat(image_dir, &statbuf)) {
     perror("image dir does not exist");
     exit (-1);
@@ -122,6 +135,12 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   case RECTWAVEGUIDE:
     strcat (drawing_filename,"rectwaveguide.jpg");
     break;
+  case COAX:
+    strcat (drawing_filename,"coax.jpg");
+    break;
+  case C_MICROSTRIP:
+    strcat (drawing_filename,"c_microstrip.jpg");
+    break;
   }
 
   free(image_dir);
@@ -133,19 +152,22 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 		       drawingbox);
     gtk_widget_show (drawingbox);
   }
+  free(drawing_filename);
+
+#else
+  gtk_widget_set_usize (twin->drawing_frame, 300, -1);
+
+#endif  /* ifdef HAVE_IMLIB */
 
   gtk_widget_show (twin->drawing_frame);
 
-  free(drawing_filename);
+
 
   /* The substrate parameters frame */
 
   twin->subparam_frame = gtk_frame_new ("Substrate Parameters");
-
   gtk_container_add (GTK_CONTAINER (vbox), twin->subparam_frame);
-
   gtk_widget_set_usize (twin->subparam_frame,300,-1);
-
   scrolledwin = gtk_scrolled_window_new (NULL, NULL);
   gtk_container_border_width(GTK_CONTAINER(scrolledwin), 5);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwin),
@@ -155,10 +177,10 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 		     scrolledwin);
   gtk_widget_set_usize (twin->subparam_frame,-1,200);
   gtk_widget_show (scrolledwin);
+  
 
-  /* Make a table of NMSUBPARS rows and 3 columns */
+  /* Make a table of NUMSUBPARS rows and 3 columns */
   twin->subparam_table = gtk_table_new (NUMSUBPARS, 3, TRUE);
-
   gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolledwin), 
 					 twin->subparam_table);
   tooltips = gtk_tooltips_new ();
@@ -181,15 +203,15 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_widget_show (labelbox);
 	break;
 
-      case 1:
+      case 1 :
 	twin->subparam_text[row] = gtk_entry_new_with_max_length (10);
 	switch (ttype) {
-	case MICROSTRIP:
+	case MICROSTRIP :
 	  switch (row) {
-	  case 2:
-	  case 3:
-	  case 4:
-	  case 7:
+	  case 2 :
+	  case 3 :
+	  case 4 :
+	  case 7 :
 	    defaultval = tvalue->subparams_value[row] * 
 	      conv_length[LENGTH_MIL][length_unit];
 	    break;
@@ -198,9 +220,27 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	    break;
 	  }
 	  break;
-	case RECTWAVEGUIDE:
+	case RECTWAVEGUIDE :
 	  defaultval = tvalue->subparams_value[row];
 	  break;
+	case COAX :
+	  defaultval = tvalue->subparams_value[row];
+	  break;
+	case C_MICROSTRIP :
+	  switch (row) {
+	  case 2 :
+	  case 3 :
+	  case 4 :
+	  case 7 :
+	    defaultval = tvalue->subparams_value[row] * 
+	      conv_length[LENGTH_MIL][length_unit];
+	    break;
+	  default:
+	    defaultval = tvalue->subparams_value[row];
+	    break;
+	  }
+	  break;
+
 	}
 
 	sprintf(textentry,"%g", (float) defaultval);
@@ -209,6 +249,10 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_table_attach_defaults (GTK_TABLE (twin->subparam_table), 
 				   twin->subparam_text[row], col, (col+1), row, (row+1));
 	gtk_widget_show (twin->subparam_text[row]);
+	if (defaultval == -1.0) {
+	  gtk_entry_set_text (GTK_ENTRY (twin->subparam_text[row]), "");
+	  gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->subparam_text[row])), FALSE);	  
+	}
 	break;
 	
       case 2:
@@ -217,36 +261,9 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 				   twin->subparam_combo[row], col, (col+1), row, (row+1));
 	gtk_widget_set_usize(twin->subparam_combo[row],4,-1);
 	gtk_widget_show (twin->subparam_combo[row]);
-	
 	break;
       }
     }
-    switch(ttype) {
-    case MICROSTRIP:
-      switch (row) {
-      case 8:
-	gtk_entry_set_text (GTK_ENTRY (twin->subparam_text[row]), "");
-	gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->subparam_text[row])), FALSE);
-	break;
-      default:
-	break;
-      }
-      break;
-    case RECTWAVEGUIDE:
-      switch (row) {
-      case 5:
-      case 6:
-      case 7:
-      case 8:
-        gtk_entry_set_text (GTK_ENTRY (twin->subparam_text[row]), "");
-        gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->subparam_text[row])), FALSE);
-        break;
-      default:
-        break;
-      }
-      break;
-    }
-
     gtk_signal_connect (GTK_OBJECT (twin->subparam_text[row]), "changed",
 			GTK_SIGNAL_FUNC (setstatus), twin);
 
@@ -264,7 +281,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 
   /* new vbox for next column*/
   vbox = gtk_vbox_new (FALSE, 5);
-  gtk_box_pack_start (GTK_BOX (hboxtop), vbox, FALSE, FALSE, 0);  
+  gtk_box_pack_start (GTK_BOX (hboxtop), vbox, TRUE, TRUE, 0);  
 
   twin->component_param_frame = gtk_frame_new ("Component Parameters");
   gtk_container_add (GTK_CONTAINER (vbox), twin->component_param_frame);
@@ -293,7 +310,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   for (row = 0; row < NUMCOMPPARS; row++) {
     for (col = 0; col < 3; col++) {
       switch (col) {
-      case 0:
+      case 0 :
 	/* Since tooltips need to be on widgets with event capability
 	 * use eventbox to locate labels and tooltips */
 	labelbox = gtk_event_box_new ();
@@ -308,10 +325,10 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_widget_show (labelbox);
 	break;
 
-      case 1:
+      case 1 :
 	twin->component_param_text[row] = gtk_entry_new_with_max_length (10);
 	switch (row) {
-	case 0:
+	case 0 :
 	  defaultval = tvalue->component_params_value[row] * 
 	    conv_freq[FREQ_GHZ][freq_unit];
 	  break;
@@ -326,9 +343,13 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_table_attach_defaults (GTK_TABLE (twin->component_param_table), 
 				   twin->component_param_text[row], col, (col+1), row, (row+1));
 	gtk_widget_show (twin->component_param_text[row]);
+	if (defaultval == -1.0) {
+	  gtk_entry_set_text (GTK_ENTRY (twin->component_param_text[row]), "");
+	  gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->component_param_text[row])), FALSE);	  
+	}
 	break;
 	
-      case 2:
+      case 2 :
 	twin->component_param_combo[row] = GTK_WIDGET (setup_combo_widget (COMPPARAMTYPE, row));
 	gtk_table_attach_defaults (GTK_TABLE (twin->component_param_table), 
 				   twin->component_param_combo[row], col, (col+1), row, (row+1));
@@ -338,15 +359,8 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	break;
       }
     }
-      switch (row) {
-      case 0:
-	break;
-      default:
-	gtk_entry_set_text (GTK_ENTRY (twin->component_param_text[row]), "");
-	gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->component_param_text[row])), FALSE);
-	break;
-      }
-      gtk_signal_connect (GTK_OBJECT (twin->component_param_text[row]), "changed",
+    
+    gtk_signal_connect (GTK_OBJECT (twin->component_param_text[row]), "changed",
 			  GTK_SIGNAL_FUNC (setstatus), twin);
   }
 
@@ -386,7 +400,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   for (row = 0; row < NUMPHYSPARS; row++) {
     for (col = 0; col < 4; col++) {
       switch (col) {
-      case 0:
+      case 0 :
 	/* Since tooltips need to be on widgets with event capability
 	 * use eventbox to locate labels and tooltips */
 	labelbox = gtk_event_box_new ();
@@ -401,13 +415,13 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_widget_show (labelbox);
 	break;
 
-      case 1:
+      case 1 :
 	twin->physical_param_text[row] = gtk_entry_new_with_max_length (10);
 	switch (ttype) {
-	case MICROSTRIP:
+	case MICROSTRIP :
 	  switch (row) {
-	  case 0:
-	  case 1:
+	  case 0 :
+	  case 1 :
 	    defaultval = tvalue->physical_params_value[row] * 
 	      conv_length[LENGTH_MIL][length_unit];
 	    break;
@@ -416,11 +430,12 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	    break;
 	  }
 	  break;
-	case RECTWAVEGUIDE:
+	case RECTWAVEGUIDE :
+	case COAX :
 	  switch (row) {
-	  case 0:
-	  case 1:
-	  case 2:
+	  case 0 :
+	  case 1 :
+	  case 2 :
 	    defaultval = tvalue->physical_params_value[row] * 
 	      conv_length[LENGTH_MIL][length_unit];
 	    break;
@@ -428,19 +443,37 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	    defaultval = tvalue->physical_params_value[row];
 	    break;
 	  }
+	case C_MICROSTRIP :
+	  switch (row) {
+	  case 0 :
+	  case 1 :
+	  case 2 :
+	    defaultval = tvalue->physical_params_value[row] * 
+	      conv_length[LENGTH_MIL][length_unit];
+	    break;
+	  default:
+	    defaultval = tvalue->physical_params_value[row];
+	    break;
+	  }
+	  break;
+	default:
+	  fprintf(stderr, "setup_transgui: unknown transmission line type!\n");
 	  break;
 	}
 	  
 	sprintf(textentry,"%g", (float) defaultval);
-
 	gtk_widget_set_usize(twin->physical_param_text[row],10,-1);
 	gtk_entry_set_text (GTK_ENTRY (twin->physical_param_text[row]), textentry);
 	gtk_table_attach_defaults (GTK_TABLE (twin->physical_param_table), 
 				   twin->physical_param_text[row], col, (col+1), row, (row+1));
 	gtk_widget_show (twin->physical_param_text[row]);
+	if (defaultval == -1.0) {
+	  gtk_entry_set_text (GTK_ENTRY (twin->physical_param_text[row]), "");
+	  gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->physical_param_text[row])), FALSE);
+	}
 	break;
 	
-      case 2:
+      case 2 :
 	twin->physical_param_combo[row] = GTK_WIDGET (setup_combo_widget (PHYSPARAMTYPE, row));
 	gtk_table_attach_defaults (GTK_TABLE (twin->physical_param_table), 
 				   twin->physical_param_combo[row], col, (col+1), row, (row+1));
@@ -448,10 +481,10 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_widget_show (twin->physical_param_combo[row]);
 
 	break;
-      case 3:
+      case 3 :
 	switch(row) {
-	case 0:
-	case 1:
+	case 0 :
+	case 1 :
 	  twin->physical_param_fix[row] = gtk_button_new_with_label("Fix");
 	  gtk_table_attach_defaults (GTK_TABLE (twin->physical_param_table), 
 				     twin->physical_param_fix[row], col, (col+1), 
@@ -465,31 +498,6 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	break;
       }
     }
-    switch(ttype) {
-    case MICROSTRIP:
-      switch (row) {
-      case 0:
-      case 1:
-	break;
-      default:
-	gtk_entry_set_text (GTK_ENTRY (twin->physical_param_text[row]), "");
-	gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->physical_param_text[row])), FALSE);
-	break;
-      }
-      break;
-    case RECTWAVEGUIDE:
-      switch (row) {
-      case 0:
-      case 1:
-      case 2:
-        break;
-      default:
-        gtk_entry_set_text (GTK_ENTRY (twin->physical_param_text[row]), "");
-        gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->physical_param_text[row])), FALSE);
-        break;
-      }
-      break;
-    }
 
     gtk_signal_connect (GTK_OBJECT (twin->physical_param_text[row]), "changed",
 		      GTK_SIGNAL_FUNC (setstatus), twin);
@@ -556,7 +564,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
   for (row = 0; row < NUMPHYSPARS; row++) {
     for (col = 0; col < 3; col++) {
       switch (col) {
-      case 0:
+      case 0 :
 	/* Since tooltips need to be on widgets with event capability
 	 * use eventbox to locate labels and tooltips */
 	labelbox = gtk_event_box_new ();
@@ -571,14 +579,14 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_widget_show (labelbox);
 	break;
 
-      case 1:
+      case 1 :
 	twin->electrical_param_text[row] = gtk_entry_new_with_max_length (10);
 	switch (row) {
-	case 0:
+	case 0 :
 	  defaultval = tvalue->electrical_params_value[row] * 
 	    conv_res[RES_OHM][res_unit];
 	  break;
-	case 1:
+	case 1 :
 	  defaultval = tvalue->electrical_params_value[row] * 
 	    conv_ang[ANG_DEG][ang_unit];
 	  break;
@@ -594,9 +602,13 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	gtk_table_attach_defaults (GTK_TABLE (twin->electrical_param_table), 
 				   twin->electrical_param_text[row], col, (col+1), row, (row+1));
 	gtk_widget_show (twin->electrical_param_text[row]);
+	if (defaultval == -1.0) {
+	  gtk_entry_set_text (GTK_ENTRY (twin->electrical_param_text[row]), "");
+	  gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->electrical_param_text[row])), FALSE);	  
+	}
 	break;
 	
-      case 2:
+      case 2 :
 	twin->electrical_param_combo[row] = GTK_WIDGET (setup_combo_widget (ELECPARAMTYPE, row));
 	gtk_table_attach_defaults (GTK_TABLE (twin->electrical_param_table), 
 				   twin->electrical_param_combo[row], col, (col+1), row, (row+1));
@@ -606,15 +618,6 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 	break;
       }
     }
-      switch (row) {
-      case 0:
-      case 1:
-	break;
-      default:
-	gtk_entry_set_text (GTK_ENTRY (twin->electrical_param_text[row]), "");
-	gtk_widget_set_sensitive ( GTK_WIDGET (GTK_ENTRY (twin->electrical_param_text[row])), FALSE);
-	break;
-      }
   }
 
 
